﻿## This file contains some of the options that can be changed to customize
## your Ren'Py game. It only contains the most common options... there
## is quite a bit more customization you can do.
##
## Lines beginning with two '#' marks are comments, and you shouldn't
## uncomment them. Lines beginning with a single '#' mark are
## commented-out code, and you may want to uncomment them when
## appropriate.

init -1 python hide:

    ## Should we enable the use of developer tools? This should be
    ## set to False before the game is released, so the user can't
    ## cheat using developer tools.

    config.developer = False

    ## These control the width and height of the screen.

    config.screen_width = 800
    config.screen_height = 600

    ## This controls the title of the window, when Ren'Py is
    ## running in a window.

    config.window_title = u"Magical Mess"
    config.window_icon = "icon.png"
    
    #########################################
    # Layouts
    
    ## This enables the use of an in-game menu that is made out of
    ## buttons.

    layout.button_menu()

    #########################################
    # Themes
    
    ## We then want to call a theme function. themes.roundrect is
    ## a theme that features the use of rounded rectangles. It's
    ## the only theme we currently support.
    ##
    ## The theme function takes a number of parameters that can
    ## customize the color scheme.

    theme.roundrect(
        # Color scheme: Watermelon Pie
                                    
        ## The color of an idle widget face.
        widget = "#FFE06D",

        ## The color of a focused widget face.
        widget_hover = "#E38A4F",

        ## The color of the text in a widget.
        widget_text = "#FAA700",

        ## The color of the text in a selected widget. (For
        ## example, the current value of a preference.)
        widget_selected = "#996600",

        ## The color of a disabled widget face. 
        disabled = "#FABF46",

        ## The color of disabled widget text.
        disabled_text = "#FFE06D",

        ## The color of informational labels.
        label = "#FCFCD7",

        ## The color of a frame containing widgets.
        frame = "#C3CD91",

        ## The background of the main menu. This can be a color
        ## beginning with '#', or an image filename. The latter
        ## should take up the full height and width of the screen.
        mm_root = "titlescreen.jpg",

        ## The background of the game menu. This can be a color
        ## beginning with '#', or an image filename. The latter
        ## should take up the full height and width of the screen.
        gm_root = "screen.jpg",

        ## If this is True, the in-game window is rounded. If False,
        ## the in-game window is square.
        rounded_window = False,

        ## And we're done with the theme. The theme will customize
        ## various styles, so if we want to change them, we should
        ## do so below.            
        )


    #########################################
    ## These settings let you customize the window containing the
    ## dialogue and narration, by replacing it with an image.

    ## The background of the window. In a Frame, the two numbers
    ## are the size of the left/right and top/bottom borders,
    ## respectively.

    style.window.background = Frame("textbox.png", 12, 12)

    ## Margin is space surrounding the window, where the background
    ## is not drawn.

    # style.window.left_margin = 6
    # style.window.right_margin = 6
    # style.window.top_margin = 6
    # style.window.bottom_margin = 6

    ## Padding is space inside the window, where the background is
    ## drawn.

    # style.window.left_padding = 6
    # style.window.right_padding = 6
    # style.window.top_padding = 6
    # style.window.bottom_padding = 6

    ## This is the minimum height of the window, including the margins
    ## and padding.

    # style.window.yminimum = 250


    #########################################
    ## This lets you change the placement of the main menu.

    ## The way placement works is that we find an anchor point
    ## inside a displayable, and a position (pos) point on the
    ## screen. We then place the displayable so the two points are
    ## at the same place.

    ## An anchor/pos can be given as an integer or a floating point
    ## number. If an integer, the number is interpreted as a number
    ## of pixels from the upper-left corner. If a floating point,
    ## the number is interpreted as a fraction of the size of the
    ## displayable or screen.

    # style.mm_menu_frame.xpos = 0.5
    # style.mm_menu_frame.xanchor = 0.5
    # style.mm_menu_frame.ypos = 0.75
    # style.mm_menu_frame.yanchor = 0.5


    #########################################
    ## These let you customize the default font used for text in Ren'Py.

    ## The file containing the default font.

    style.default.font = "lamebrain.ttf"

    ## The default size of text.

    style.default.size = 23

    ## Note that these only change the size of some of the text. Other
    ## buttons have their own styles.


    #########################################
    ## These settings let you change some of the sounds that are used by
    ## Ren'Py.

    ## Set this to False if the game does not have any sound effects.

    config.has_sound = True

    ## Set this to False if the game does not have any music.

    config.has_music = True

    ## Set this to False if the game does not have voicing.

    config.has_voice = True

    ## Sounds that are used when button and imagemaps are clicked.

    # style.button.activate_sound = "click.wav"
    # style.imagemap.activate_sound = "click.wav"

    ## Sounds that are used when entering and exiting the game menu.

    # config.enter_sound = "click.wav"
    # config.exit_sound = "click.wav"

    ## A sample sound that can be played to check the sound volume.

    # config.sample_sound = "click.wav"

    ## Music that is played while the user is at the main menu.

    config.main_menu_music = "mainmenu.mp3"


    #########################################
    ## Help.

    ## This lets you configure the help option on the Ren'Py menus.
    ## It may be:
    ## - A label in the script, in which case that label is called to
    ##   show help to the user.
    ## - A file name relative to the base directory, which is opened in a
    ##   web browser.
    ## - None, to disable help.   
    config.help = "README.txt"


    #########################################
    ## Transitions.

    ## Used when entering the game menu from the game.
    config.enter_transition = fade

    ## Used when exiting the game menu to the game.
    config.exit_transition = fade

    ## Used between screens of the game menu.
    config.intra_transition = fade

    ## Used when entering the game menu from the main menu.
    config.main_game_transition = fade

    ## Used when returning to the main menu from the game.
    config.game_main_transition = fade

    ## Used when entering the main menu from the splashscreen.
    config.end_splash_transition = None

    ## Used when entering the main menu after the game has ended.
    config.end_game_transition = fade

    ## Used when a game is loaded.
    config.after_load_transition = None

    ## Used when the window is shown.
    config.window_show_transition = None

    ## Used when the window is hidden.
    config.window_hide_transition = None


    #########################################
    ## This is the name of the directory where the game's data is
    ## stored. (It needs to be set early, before any other init code
    ## is run, so the persisten information can be found by the init code.)
python early:
    config.save_directory = "Magical Mess-1312692426"

init -1 python hide:
    #########################################
    ## Default values of Preferences.

    ## Note: These options are only evaluated the first time a
    ## game is run. To have them run a second time, delete
    ## game/saves/persistent

    ## Should we start in fullscreen mode?

    config.default_fullscreen = False

    ## The default text speed in characters per second. 25 is infinite.

    config.default_text_cps = 25

    #########################################
    ## More customizations can go here.
    
    
    config.main_menu = [
        (u"Play", "start", "True"),
        (u"Continue", _intra_jumps("load_screen", "main_game_transition"), "True"),
        (u"Settings", _intra_jumps("preferences_screen", "main_game_transition"), "True"),
        (u"Quit", ui.jumps("_quit"), "True")
        ]

init python:

    # Give us some space on the right side of the screen.
    style.window.right_padding = 100

    def toggle_skipping():
        config.skipping = not config.skipping

    show_button_game_menu = True

    def button_game_menu():
        
        if show_button_game_menu:

            # to save typing
            ccinc = renpy.curried_call_in_new_context

            ui.vbox(xpos=0.99, ypos=0.98, xanchor='right', yanchor='bottom')
            ui.textbutton("Save", clicked=ccinc("_game_menu_save"), xminimum=80)
            ui.textbutton("Load", clicked=ccinc("_game_menu_load"), xminimum=80)
            ui.textbutton("Setts", clicked=ccinc("_game_menu_preferences"), xminimum=80)
            ui.close()

    config.window_overlay_functions.append(button_game_menu)
    
    
init -1:
              
    python:
        style.create('gallery_pages', 'default')
        style.create('gallery_page_button', 'button')
        style.create('gallery_page_button_text', 'button_text')
        style.create('gallery_return_button', 'button')
        style.create('gallery_return_button_text', 'button_text')
        style.create('gallery_button_image', 'default')
        style.create('gallery_image', 'image_placement')
        style.create('gallery_grid', 'default')
        style.create('gallery_button', 'default')


        # The function that actually manages the display of the image
        # gallery.
        def gallery():

            def show_things(what):
                if isinstance(what, tuple):
                    for i in what:
                        show_things(i)

                elif isinstance(what, (str, unicode)):
                    ui.image(what)
                else:
                    ui.add(what)

            page = 0

            while True:

                images = gallery_pages[page][1]
                ui.image(gallery_pages[page][2])

                # Show the names of the various gallery pages.

                ui.window(style='gallery_pages')
                ui.vbox(focus="gallery_pages")

                for i in range(0, len(gallery_pages)):
                    if i == page:
                        clicked = None
                    else:
                        clicked = ui.returns(("page", i))

                    ui.textbutton(gallery_pages[i][0],
                              style='gallery_page_button',
                              text_style='gallery_page_button_text',
                              clicked=clicked)
                ui.close()

                # Show the return button.
                ui.textbutton('Return',
                              style='gallery_return_button',
                              text_style='gallery_return_button_text',
                              clicked=ui.returns(("return", None)))

                # Show the grid for this page.
                ui.grid(gallery_cols, gallery_rows, style='gallery_grid')

                # For each grid cell.
                for i in range(0, gallery_cols * gallery_rows):

                    # Fill empty space with nulls.
                    if i >= len(images):
                        ui.null()
                        continue

                    # Otherwise, get the filename and spec and see if
                    # we've unlocked it.
                    if len(images[i]) == 2:
                        filename, spec = images[i]
                        toshow = filename
                    elif len(images[i]) == 3:
                        toshow, spec, filename = images[i]

                    if spec:
                        spec = spec.split()
                        
                    if spec and tuple(spec) not in persistent._seen_images:
                        filename = None
                        clicked = None
                    else:
                        clicked = ui.returns(('show', toshow))

                    # Create the button, containing the appropriate
                    # image or a null if we haven't unlocked it yet.
                    
                    ui.button(style='gallery_button', clicked=clicked)

                    if not filename:
                        ui.null(width=gallery_width, height=gallery_height)
                    else:
                        
                        if renpy.loadable("thumbnail_" + filename):
                            ui.image("thumbnail_" + filename,
                                     style="gallery_button_image")
                        else:
                            ui.add(im.Scale(filename,
                                            gallery_width,
                                            gallery_height))
                            
                ui.close()

                # Interact with the user.
                renpy.transition(gallery_transition)
                cmd, arg = ui.interact(suppress_overlay=True, suppress_underlay=True)

                # Process the user's commands.
                if cmd == "show":

                    if not isinstance(arg, list):
                        arg = [ arg ]

                    for i in arg:
                        ui.add(Solid((0, 0, 0, 255)))
                        show_things(i)
                        ui.saybehavior()
                        renpy.transition(gallery_transition)
                        ui.interact(suppress_overlay=True, suppress_underlay=True)

                if cmd == "page":
                    page = arg

                if cmd == "return":
                    renpy.transition(gallery_transition)
                    return


        library.main_menu.insert(2, ("CG Gallery", ui.jumps("gallery"), 'True'))


label gallery:

    $ gallery()

    jump _main_menu

    


